#
# spec file for package python-azure-identity-broker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-identity-broker
Version:        1.2.0
Release:        1.3
Summary:        Microsoft Azure Identity Broker plugin for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure_identity_broker/azure_identity_broker-%{version}.tar.gz
BuildRequires:  %{python_module azure-identity < 2.0.0}
BuildRequires:  %{python_module azure-identity >= 1.14.0}
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-nspkg >= 3.0.0
Requires:       (python-azure-identity >= 1.18.0 with python-azure-identity < 2.0.0)
Requires:       (python-msal >= 1.31.0 with python-msal < 2.0.0)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-identity-broker < 1.0.0
%endif
BuildArch:      noarch
%python_subpackages

%description
This package extends the Azure Identity library by providing supplemental
credentials for authenticating via an authentication broker.

An authentication broker is an application that runs on a user’s machine that
manages the authentication handshakes and token maintenance for connected
accounts. Currently, only the Windows authentication broker, Web Account
Manager (WAM), is supported.

%prep
%setup -q -n azure_identity_broker-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/azure/identity/broker
%{python_sitelib}/azure_identity_broker-*.dist-info

%changelog
* Wed Oct  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Adjust upstream source name in spec file
- Drop extra LICENSE.txt as upstream now ships its own
- Rename LICENSE.txt to LICENSE in %%files section
- Update Requires from setup.py
* Thu Apr 11 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Use modern RPM macros to express version dependencies
* Tue Dec 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.0.0
